supercharged_plus library

Supercharged brings all the comfort features from languages like Kotlin to all Flutter developers.

Start supercharging your code by importing it:

import 'package:supercharged_plus/supercharged_plus.dart';

Classes

DeltaOffset
Supercharged helper to create an Offset based on directional deltas.
Supercharged
Importer helper class. Does nothing.

Extensions

AnimatableSCF on Animatable<T>
Supercharged Flutter extension on Animatable objects.
AnimationSCF on Animation<double>
Supercharged Flutter extension on Animation objects.
ColorSCF on Color
Supercharged Flutter extension on Color objects.
ContextUtils on BuildContext
Supercharged extension on BuildContext for UI convenience.
DateTimeSC on DateTime
Supercharged extension on DateTime objects.
DoubleSC on double
Supercharged extensions on double numbers.
DoubleSCF on double
Supercharged Flutter extensions on double numbers.
DurationSC on Duration
Supercharged extensions on Duration.
IntSC on int
Supercharged extensions on int numbers.
IntSCF on int
Supercharged Flutter extensions on int numbers.
IterableOfDoubleSC on Iterable<double>
Supercharged extensions on Iterable<double> like List<double> and Set<double>.
IterableOfIntSC on Iterable<int>
Supercharged extensions on Iterable<int> like List<int> and Set<int>.
IterableOfMapEntrySC on Iterable<MapEntry<K, V>>
Supercharged extensions on Iterable<MapEntry> like List<MapEntry> and Set<MapEntry>.
IterableSC on Iterable<T>
Supercharged extensions on Iterables like List and Set.
ListSC on List<T>
Supercharged extensions on List.
ListSort on List<Comparable<T>>
MapSC on Map<K, V>
Supercharged extensions on Map.
OffsetSCF on Offset
Supercharged Flutter extensions on Offset.
RectSCF on Rect
Supercharged Flutter extensions on Rect.
SizeSCF on Size
Supercharged Flutter extensions on Size.
StringSC on String
Supercharged extensions on String.
StringSCF on String
Supercharged Flutter extensions on String.
WidgetSC on Widget
Extension methods for Widget to simplify layout wrapper creation.

Functions

sortAsc<T>(Comparable<T> a, T b) int
A supercharged helper that sorts a list ascending. For example:
sortDesc<T>(T a, Comparable<T> b) int
A supercharged helper that sorts a list ascending. For example:
throwIf(bool test, Error errorFactoryFunc()) → void
Throws an Error if predicate test is satisfied
throwIfNot(bool test, Error errorFactoryFunc()) → void
Throws an Error if predicate test is not satisfied